Struct TtlValue
pub struct TtlValue<T> { /* private fields */ }Expand description
A value that expires after some time.
This value is (de)serializable so it can be persisted in a store.
Implementations
impl<T> TtlValue<T>
impl<T> TtlValue<T>
pub const STALE_THRESHOLD: f64
pub const STALE_THRESHOLD: f64
The number of milliseconds after which the data is considered stale.
This matches 1 day.
pub fn without_expiry(data: T) -> TtlValue<T>
pub fn without_expiry(data: T) -> TtlValue<T>
Construct a new TtlValue with the given data that never expires.
pub fn map<U, F>(self, f: F) -> TtlValue<U>where
F: FnOnce(T) -> U,
pub fn map<U, F>(self, f: F) -> TtlValue<U>where
F: FnOnce(T) -> U,
Transform the data of this TtlValue with the given function.
pub fn has_expired(&self) -> bool
pub fn has_expired(&self) -> bool
Whether this value has expired.
pub fn expire(&mut self)
pub fn expire(&mut self)
Mark this value has expired.
pub fn into_data(self) -> T
pub fn into_data(self) -> T
Get the data of this value.